/*
 * Copyright 2012 htfv (Aliaksei Lahachou)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.htfv.utils.el.internal;

import javax.el.ELContext;
import javax.el.ELResolver;
import javax.el.FunctionMapper;
import javax.el.VariableMapper;

import com.github.htfv.utils.el.PropertySource;

/**
 * Implements Build Configurator specific evaluation context.
 *
 * {@code BuildConfiguratorELContext} object may and should be reused within one
 * mojo execution, because it caches results of expression evaluations. It may
 * not be reused between multiple executions, because it is not thread-safe.
 *
 * @author htfv (Aliaksei Lahachou)
 */
public class DefaultELContext extends ELContext
{
    /**
     * Creates a new instance of {@code BuildConfiguratorELContext}.
     *
     * @param mavenProject
     *            reference to the configured Maven project. Used to resolve
     *            properties referenced in EL expressions.
     * @param loadedPropertyFiles
     *            loaded property files.
     *
     * @return new instance of {@code BuildConfiguratorELContext}.
     */
    public static ELContext newInstance(final PropertySource... propertySources)
    {
        return new DefaultELContext(propertySources);
    }

    /**
     * Build Configurator specific EL resolver.
     */
    private final ELResolver elResolver;

    /**
     * Constructs a new {@code BuildConfiguratorELContext} object.
     *
     * @param mavenProject
     *            reference to the configured Maven project. Used to resolve
     *            properties referenced in EL expressions.
     * @param loadedPropertyFiles
     *            loaded property files.
     */
    protected DefaultELContext(final PropertySource... propertySources)
    {
        this.elResolver = DefaultELResolver.newInstance(propertySources);
    }

    @Override
    public ELResolver getELResolver()
    {
        return elResolver;
    }

    @Override
    public FunctionMapper getFunctionMapper()
    {
        return DefaultFunctionMapper.getInstance();
    }

    @Override
    public VariableMapper getVariableMapper()
    {
        return DefaultVariableMapper.getInstance();
    }
}
