/*
 * Copyright 2012 htfv (Aliaksei Lahachou)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.htfv.utils.el.internal;

import javax.el.ValueExpression;
import javax.el.VariableMapper;

/**
 * Implements a variable mapper which does not resolve or set any variable.
 *
 * @author htfv (Aliaksei Lahachou)
 */
public class DefaultVariableMapper extends VariableMapper
{
    /**
     * Caches reference to the {@link DefaultVariableMapper} singleton.
     *
     * @author htfv (Aliaksei Lahachou)
     */
    private static class Singleton
    {
        /**
         * Reference to the {@link DefaultVariableMapper} singleton.
         */
        public static final VariableMapper INSTANCE = new DefaultVariableMapper();
    }

    /**
     * Returns reference to the {@link DefaultVariableMapper} singleton. Because
     * {@code DefaultVariableMapper} does not have state, it may be reused
     * without restrictions.
     *
     * @return reference to the {@link DefaultVariableMapper} singleton.
     */
    public static VariableMapper getInstance()
    {
        return Singleton.INSTANCE;
    }

    @Override
    public ValueExpression resolveVariable(final String variable)
    {
        return null;
    }

    @Override
    public ValueExpression setVariable(final String variable, final ValueExpression expression)
    {
        return null;
    }
}
