/*
 * Copyright 2012 htfv (Aliaksei Lahachou)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.htfv.utils.el.internal;

import java.util.Collection;
import java.util.Map;
import java.util.Set;

import javax.el.ELContext;

import org.apache.commons.lang3.ObjectUtils;

/**
 * Implements {@code prop} EL object for accessing properties with arbitrary
 * names.
 *
 * @author htfv (Aliaksei Lahachou)
 */
public class PropertyAccessor implements Map<String, String>
{
    /**
     * {@link ELContext} used to resolve EL expressions.
     */
    private final ELContext context;

    /**
     * {@link BuildConfiguratorELResolver} used to resolve.
     */
    private final DefaultELResolver resolver;

    /**
     * Constructs a new {@link PropertyAccessor} object.
     *
     * @param resolver
     *            {@link BuildConfiguratorELResolver} used to resolve
     *            properties.
     * @param context
     *            {@link ELContext} used to resolve EL expressions.
     */
    public PropertyAccessor(final DefaultELResolver resolver, final ELContext context)
    {
        this.context  = context;
        this.resolver = resolver;
    }

    @Override
    public void clear()
    {
    }

    @Override
    public boolean containsKey(final Object key)
    {
        return false;
    }

    @Override
    public boolean containsValue(final Object value)
    {
        return false;
    }

    @Override
    public Set<Entry<String, String>> entrySet()
    {
        return null;
    }

    @Override
    public String get(final Object key)
    {
        return ObjectUtils.toString(
                resolver.resolve(context, key.toString()),
                null);
    }

    @Override
    public boolean isEmpty()
    {
        return false;
    }

    @Override
    public Set<String> keySet()
    {
        return null;
    }

    @Override
    public String put(final String key, final String value)
    {
        return null;
    }

    @Override
    public void putAll(final Map<? extends String, ? extends String> m)
    {
    }

    @Override
    public String remove(final Object key)
    {
        return null;
    }

    @Override
    public int size()
    {
        return 0;
    }

    @Override
    public Collection<String> values()
    {
        return null;
    }
}
